#!/bin/bash

if [ -f "run.local" ]; then
    source run.local
fi

TODAY=$(date +%G-%m-%d)
HERE=$(pwd)
RESULT_DIR=$HERE/results/$(hostname)

SRC_DIR=$HERE/src
CORE_DIR=$SRC_DIR/ufo-core
PLUGIN_DIR=$SRC_DIR/ufo-filters

CORE_BUILD_DIR=$CORE_DIR/build
PLUGIN_BUILD_DIR=$PLUGIN_DIR/build
INSTALL_DIR=$HERE/install


# clear build and install dir to start from scratch
rm -rf $CORE_BUILD_DIR $PLUGIN_BUILD_DIR $INSTALL_DIR
mkdir -p $SRC_DIR $INSTALL_DIR $RESULT_DIR


# build ufo-core
if [ ! -d "$CORE_DIR" ]; then
    cd $SRC_DIR
    git clone https://github.com/ufo-kit/ufo-core
    cd $HERE
else
    cd $CORE_DIR
    git pull
    cd $HERE
fi

mkdir -p $CORE_BUILD_DIR
cd $CORE_BUILD_DIR
cmake $CORE_DIR -DPREFIX=$INSTALL_DIR
make && make install

# build ufo-filters
if [ ! -d "$PLUGIN_DIR" ]; then
    cd $SRC_DIR
    git clone https://github.com/ufo-kit/ufo-filters
    cd $HERE
else
    cd $PLUGIN_DIR
    git pull
    cd $HERE
fi

export PATH=$INSTALL_DIR/bin:$PATH
export LD_LIBRARY_PATH=$INSTALL_DIR/lib:$LD_LIBRARY_PATH
export PKG_CONFIG_PATH=$INSTALL_DIR/lib/pkgconfig

mkdir -p $PLUGIN_BUILD_DIR && cd $PLUGIN_BUILD_DIR
cmake $PLUGIN_DIR -DPREFIX=$INSTALL_DIR
make && make install

launch () {
    result=$(ufo-launch $2 | grep -o "[0-9]*\.[0-9]*s" | sed 's/.$//')
    printf "$1 $result\n" >> $RESULT_DIR/$TODAY.txt
}

launch "fft"            "dummy-data width=2048 height=2048 number=100 ! fft ! null download=true"
launch "roundtrip"      "dummy-data width=2048 height=2048 number=100 ! fft ! ifft ! null download=true"
launch "backproject"    "dummy-data width=2048 height=2048 number=100 ! backproject ! null download=true"
